@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 use Dist::Zilla;
 
@@ -139,7 +139,10 @@ has _has_xs => (
     is      => 'ro',
     isa     => 'Bool',
     lazy    => 1,
-    default => sub { !!( scalar glob('*.xs') ) },
+    default => sub {
+        my $rule = Path::Iterator::Rule->new;
+        return scalar $rule->file->name(qr/\.xs$/)->all('.') ? 1 : 0;
+    },
 );
 
 has pod_coverage_class => (
@@ -706,7 +709,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.53
+version 0.54
 
 =head1 DESCRIPTION
 
